@@ -21,10 +21,13 @@ public:
 
     bool trySetTransformationMode(Qt::TransformationMode mode, float scaleHint);
 
+    bool togglePauseAnimation();
+    bool skipAnimationFrame(int delta = 1);
+
     QPixmap renderToPixmap();
 
 private:
-    QGraphicsItem * m_theThing;
+    QGraphicsItem * m_theThing = nullptr;
 };
 
 #endif // GRAPHICSSCENE_H
