@@ -15,7 +15,7 @@ class GraphicsView : public QGraphicsView
 public:
     GraphicsView(QWidget *parent = nullptr);
 
-    void showFileFromPath(const QString &filePath, bool requestGallery = false);
+    void showFileFromPath(const QString &filePath);
 
     void showImage(const QPixmap &pixmap);
     void showImage(const QImage &image);
@@ -48,7 +48,6 @@ public:
 signals:
     void navigatorViewRequired(bool required, QTransform transform);
     void viewportRectChanged();
-    void requestGallery(const QString &filePath);
 
 public slots:
     void toggleCheckerboard(bool invertCheckerboardColor = false);
@@ -60,10 +59,6 @@ private:
     void wheelEvent(QWheelEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
 
-    void dragEnterEvent(QDragEnterEvent *event) override;
-    void dragMoveEvent(QDragMoveEvent *event) override;
-    void dropEvent(QDropEvent *event) override;
-
     bool isThingSmallerThanWindowWith(const QTransform &transform) const;
     bool shouldIgnoreMousePressMoveEvent(const QMouseEvent *event) const;
     void setCheckerboardEnabled(bool enabled, bool invertColor = false);
@@ -75,7 +70,7 @@ private:
     bool m_enableFitInView = false;
     bool m_avoidResetTransform = false;
     bool m_checkerboardEnabled = false;
-    bool m_isLastCheckerboardColorInverted = false;
+    bool m_useLightCheckerboard = false;
 };
 
 #endif // GRAPHICSVIEW_H
