@@ -7,17 +7,16 @@
 #include "playlistmanager.h"
 #include "settings.h"
 
+#ifdef Q_OS_MACOS
+#include "fileopeneventhandler.h"
+#endif // Q_OS_MACOS
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDir>
 #include <QTranslator>
 #include <QUrl>
 
-// QM_FILE_INSTALL_DIR should be defined from the CMakeLists file.
-#ifndef QM_FILE_INSTALL_DIR
-#define QM_FILE_INSTALL_DIR ":/i18n/"
-#endif // QM_FILE_INSTALL_DIR
-
 int main(int argc, char *argv[])
 {
     QCoreApplication::setApplicationName("Pineapple Pictures");
@@ -30,11 +29,12 @@ int main(int argc, char *argv[])
 #endif
 
     QTranslator translator;
-    QString qmDir;
-#ifdef _WIN32
-    qmDir = QDir(QCoreApplication::applicationDirPath()).absoluteFilePath("translations");
+#if defined(TRANSLATION_RESOURCE_EMBEDDING)
+    const QString qmDir = QLatin1String(":/i18n/");
+#elif defined(QM_FILE_INSTALL_ABSOLUTE_DIR)
+    const QString qmDir = QT_STRINGIFY(QM_FILE_INSTALL_ABSOLUTE_DIR);
 #else
-    qmDir = QT_STRINGIFY(QM_FILE_INSTALL_DIR);
+    const QString qmDir = QDir(QCoreApplication::applicationDirPath()).absoluteFilePath("translations");
 #endif
     if (translator.load(QLocale(), QLatin1String("PineapplePictures"), QLatin1String("_"), qmDir)) {
         QCoreApplication::installTranslator(&translator);
@@ -59,6 +59,21 @@ int main(int argc, char *argv[])
     MainWindow w;
     w.show();
 
+#ifdef Q_OS_MACOS
+    FileOpenEventHandler * fileOpenEventHandler = new FileOpenEventHandler(&a);
+    a.installEventFilter(fileOpenEventHandler);
+    a.connect(fileOpenEventHandler, &FileOpenEventHandler::fileOpen, [&w](const QUrl & url){
+        if (w.isHidden()) {
+            w.setWindowOpacity(1);
+            w.showNormal();
+        } else {
+            w.activateWindow();
+        }
+        w.showUrls({url});
+        w.initWindowSize();
+    });
+#endif // Q_OS_MACOS
+
     QStringList urlStrList = parser.positionalArguments();
     QList<QUrl> && urlList = PlaylistManager::convertToUrlList(urlStrList);
 
